@@ -64,7 +64,7 @@ extern short help_up;
 /* xcircuit.h!							*/
 /*--------------------------------------------------------------*/
 
-static char *function_names[NUM_FUNCTIONS] = {
+static char *function_names[NUM_FUNCTIONS + 1] = {
    "Page", "Justify", "Superscript", "Subscript", "Normalscript",
    "Nextfont", "Boldfont", "Italicfont", "Normalfont", "Underline",
    "Overline", "ISO Encoding", "Return", "Halfspace", "Quarterspace",
@@ -76,20 +76,22 @@ static char *function_names[NUM_FUNCTIONS] = {
    "Next Point", "Attach", "Next Library", "Library Directory",
    "Library Move", "Library Copy", "Library Edit", "Library Delete",
    "Library Duplicate", "Library Hide", "Library Virtual Copy",
-   "Page Directory ", "Library Pop",
+   "Page Directory", "Library Pop",
    "Help", "Redraw", "View", "Zoom In", "Zoom Out", "Pan",
    "Double Snap", "Halve Snap", "Pan Left", "Pan Right", "Pan Up",
-   "Pan Down", "Write", "Rotate", "Flip X", "Flip Y", "Snap", "Snap To"
+   "Pan Down", "Write", "Rotate", "Flip X", "Flip Y", "Snap", "Snap To",
    "Pop", "Push", "Delete", "Select", "Box", "Arc", "Text",
    "Exchange", "Copy", "Join", "Unjoin", "Spline", "Edit",
    "Undelete", "Select Save", "Unselect", "Dashed", "Dotted",
    "Solid", "Prompt", "Dot", "Wire", "Start", "Finish", "Cancel",
-   "Nothing", "Exit"
+   "Nothing", "Exit",
 
 #ifdef SCHEMA
-   , "Netlist", "Swap", "Pin Label", "Pin Global", "Info Label",
-   "Connectivity", "Sim", "SPICE", "PCB", "SPICE Flat"
+   "Netlist", "Swap", "Pin Label", "Pin Global", "Info Label",
+   "Connectivity", "Sim", "SPICE", "PCB", "SPICE Flat",
 #endif
+
+   NULL			/* sentinel */
 };
 
 /*--------------------------------------------------------------*/
@@ -181,8 +183,14 @@ int string_to_func(const char *funcstring, short *value)
    int i;
 
    for (i = 0; i < NUM_FUNCTIONS; i++)
+   {
+      if (function_names[i] == NULL) {
+	 Fprintf(stderr, "Error: resolve bindings and function strings!\n");
+	 return -1;	  /* should not happen? */
+      }
       if (!strcmp(funcstring, function_names[i]))
 	 return i;
+   }
 
    /* Check if this string might have a value attached */
 
