@@ -11,6 +11,7 @@ extern Tk_EventProc *xctk_drag(ClientData, XEvent *);
 extern Tk_EventProc *xctk_draglscroll(ClientData, XEvent *);
 extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
+extern objectptr NameToObject(char *, objinstptr *, Boolean);
 
 #endif
 
@@ -201,10 +202,11 @@ extern char *varscan(objectptr, char *, short *, genericptr, u_char);
 extern char *varfscan(objectptr, char *, float *, genericptr, u_char);
 extern objinstptr addtoinstlist(int, objectptr, Boolean);
 extern Boolean objectread(FILE *, objectptr, short, short, short, char *, int);
-extern void setfile(xcWidget, xcWidget, caddr_t);
 #ifdef TCL_WRAPPER
+void setfile(char *, int);
 extern xcTimeOutProc savetemp(caddr_t);
 #else
+extern void setfile(xcWidget, xcWidget, caddr_t);
 extern xcTimeOutProc savetemp(caddr_t, xcIntervalId *);
 #endif
 extern void savelibpopup(xcWidget, pointertype, caddr_t);
@@ -347,6 +349,7 @@ extern short findhelvetica();
 extern void catreturn();
 extern int pageposition(short, XButtonEvent *, int);
 extern short pagelinks();
+extern short *pagetotals(int, short);
 extern int is_page(objectptr);
 extern int is_library(objectptr);
 extern void pagecatbutton(XButtonEvent *);
@@ -468,7 +471,7 @@ extern void dospecial(void);
 /* from netlist.c: */
 
 #ifdef SCHEMA
-extern void createnets();
+extern void createnets(objinstptr);
 extern void destroynets();
 extern void gennet(char *, char *);
 extern Boolean nonnetwork(polyptr);
@@ -602,7 +605,8 @@ extern void pinconvert(labelptr, pointertype);
 extern void dopintype(xcWidget, pointertype, caddr_t);
 extern void setsymschem();
 extern int findpageobj(objectptr);
-extern int findsubschems(int, objectptr, int);
+extern void collectsubschems(int);
+extern int findsubschems(int, objectptr, int, short *);
 extern void copypinlabel(labelptr);
 extern int checkschem(objectptr, char *);
 extern int checksym(objectptr, char *);
